grammar Template;

@parser::header {
package com.springsource.bundlor.support.parse;

import java.util.Map;
import java.util.HashMap;

import com.springsource.server.osgi.manifest.parse.HeaderDeclaration;
import com.springsource.server.osgi.manifest.parse.ImmutableHeaderDeclaration;
}

@parser::members {

private List<String> names;	
private Map<String, String> attributes;
private Map<String, String> directives = new HashMap<String, String>();
protected List<HeaderDeclaration> declarations = new ArrayList<HeaderDeclaration>();
    
protected void displayError(RecognitionException e){
}

public List<HeaderDeclaration> getDeclarations() {
return this.declarations;
}    
}

@lexer::header {
package com.springsource.bundlor.support.parse;

} 

@lexer::members {


}


@rulecatch {
catch(RecognitionException e) {
	input.consume();
	displayError(e);
	//throw e;
}
}

//  ############### HERE BEGINS THE MAIN RULE SECTION FOR THE PARSER ###############


// Additions for DynamicImport-Package ...
packageTemplate 	:	packageTemplateDecl (',' packageTemplateDecl) *
	;
	
packageTemplateDecl
@init {
this.names = new ArrayList<String>();
this.attributes = new HashMap<String, String>();
this.directives = new HashMap<String, String>();
}
@after {
this.declarations.add(new ImmutableHeaderDeclaration(this.names, this.attributes, this.directives));
}	
	: packageTemplatePkgNames  (';' parameter) *
	;

packageTemplatePkgNames
	: packageTemplatePkgName (';' packageTemplatePkgName) * 
	;
	
packageTemplatePkgName 
	: 	
		wildcardedPackageName |
		star |
		packageName
		
	;
// ... end of additions for DynamicImport-Package.

		
parameter 
	:	directive | attribute
	;
	
directive
	:	identifier ':=' argument {this.directives.put($identifier.text, $argument.text);}
	;

attribute
	:	identifier '=' argument {this.attributes.put($identifier.text, $argument.text);}
	;

argument
	: 	identifier | QUOTED_STRING
	;

/*
 Note that the JLS allows a diverse set of Unicode characters, such as Greek characters, in package names. This grammar is more restrictive.
 See [ENGINE-303].
 */
packageName 
	: packageIdentifier {this.names.add($packageIdentifier.text);}
	;

wildcardedPackageName
	: wildPackageIdentifier {this.names.add($wildPackageIdentifier.text);}
	;
	
star
	: STAR {this.names.add($STAR.text);}
	;

QUOTED_STRING
	:  '"' (~('\\' | '"' | '\r' | '\n') | '\\' ('\\' | '"')) * '"'
	{setText(getText().substring(1, getText().length() -1));}
	;
	
identifier
	: identifierPart ('.' identifierPart) *
	;
	
packageIdentifier
	: packageIdentifierPart ('.' packageIdentifierPart) *
	;
	
wildPackageIdentifier
	: packageIdentifierPart ('.' packageIdentifierPart) * DOTSTAR
	;
	
identifierPart
	: (ALPHA | DIGIT | '_' | '-') +
	;

packageIdentifierPart
	: (ALPHA | DIGIT | '_' | '$') +
	;

DIGIT	:	'0'..'9'
	;
	
ALPHA	:	'a'..'z' | 'A'..'Z'
	;
	
DOTSTAR : '.*'
	;
	
STAR : '*'
	;

WS	:	' '+ {skip();}
	;
	
